@@ -1,4 +1,6 @@
-import pytest  # noqa
+# type: ignore
+
+import pytest
 
 from basicco.recursive_repr import recursive_repr
 
@@ -8,7 +10,7 @@ def test_recursive_repr():
     def my_repr(_self, prefix="MyRepr<", suffix=">"):
         return prefix + my_repr(_self) + suffix
 
-    assert my_repr(object()) == "MyRepr<...>"  # type: ignore
+    assert my_repr(object()) == "MyRepr<...>"
 
 
 if __name__ == "__main__":
