@@ -1,7 +1,10 @@
+# type: ignore
+
 import abc
 import itertools
 
-import pytest  # noqa
+import pytest
+import six
 import tippo
 
 from basicco.type_checking import (
@@ -45,13 +48,15 @@ def test_format_types():
     assert format_types(tippo.Union[float, bool]) == (float, bool)
     assert format_types((tippo.Union[float, bool], None)) == (float, bool, type(None))
     with pytest.raises(TypeError):
-        format_types(3)  # type: ignore
+        format_types(3)
 
 
 def test_type_names():
     assert type_names(None) == (type(None).__name__,)
     assert type_names((None,)) == (type(None).__name__,)
-    assert type_names(("module.module.Cls", "abc.abstractmethod", abc.ABCMeta, itertools.chain)) == (
+    assert type_names(
+        ("module.module.Cls", "abc.abstractmethod", abc.ABCMeta, itertools.chain)
+    ) == (
         "Cls",
         "abstractmethod",
         "ABCMeta",
@@ -75,6 +80,17 @@ def test_is_instance():
     assert not is_instance(0, None)
     assert not is_instance(0, (None,))
 
+    assert is_instance("a", str)
+    assert is_instance("a", six.text_type)
+    assert is_instance(six.text_type("a"), six.text_type)
+    assert is_instance(six.text_type("a"), str)
+
+    for integer_type in six.integer_types:
+        assert is_instance(2, int)
+        assert is_instance(2, integer_type)
+        assert is_instance(integer_type(2), integer_type)
+        assert is_instance(integer_type(2), int)
+
     assert is_instance(Cls(), cls_path) is True
     assert is_instance(Cls(), cls_path, subtypes=False) is True
     assert is_instance(SubCls(), cls_path) is True
@@ -209,19 +225,19 @@ def test_assert_is_subclass():
     assert_is_subclass(SubCls, (subcls_path, SubCls, int), subtypes=False)
 
     with pytest.raises(TypeCheckError):
-        assert_is_subclass(Cls, (int, float))  # type: ignore
+        assert_is_subclass(Cls, (int, float))
 
     with pytest.raises(TypeCheckError):
-        assert_is_subclass(Cls, (int, float), subtypes=False)  # type: ignore
+        assert_is_subclass(Cls, (int, float), subtypes=False)
 
     with pytest.raises(TypeCheckError):
-        assert_is_subclass(SubCls, (int, float))  # type: ignore
+        assert_is_subclass(SubCls, (int, float))
 
     with pytest.raises(TypeCheckError):
-        assert_is_subclass(SubCls, (int, float), subtypes=False)  # type: ignore
+        assert_is_subclass(SubCls, (int, float), subtypes=False)
 
     with pytest.raises(TypeCheckError):
-        assert_is_subclass(SubCls, (int, float), subtypes=False)  # type: ignore
+        assert_is_subclass(SubCls, (int, float), subtypes=False)
 
     with pytest.raises(ValueError):
         assert_is_subclass(Cls, ())
@@ -234,15 +250,15 @@ def test_assert_is_callable():
     assert_is_callable(int)
 
     with pytest.raises(TypeCheckError):
-        assert_is_callable(3)  # type: ignore
+        assert_is_callable(3)
 
 
 def test_assert_is_iterable():
     with pytest.raises(TypeCheckError):
-        assert_is_iterable(3)  # type: ignore
+        assert_is_iterable(3)
 
     with pytest.raises(TypeCheckError):
-        assert_is_iterable(False)  # type: ignore
+        assert_is_iterable(False)
 
     with pytest.raises(TypeCheckError):
         assert_is_iterable("foo")
@@ -258,10 +274,14 @@ def test_typing_type():
     assert is_instance(3.0, float) == isinstance(3.0, float)
     assert is_instance(float, tippo.Type[float]) == is_subclass(float, float)
 
-    assert is_subclass(float, tippo.Type[tippo.Type[float]]) == is_subclass(float, type(float))
+    assert is_subclass(float, tippo.Type[tippo.Type[float]]) == is_subclass(
+        float, type(float)
+    )
     assert is_subclass(float, tippo.Type[int]) == is_subclass(float, type)
 
     assert is_instance({"a": 1}, tippo.Mapping[str, int])
+    assert is_instance({six.text_type("a"): 1}, tippo.Mapping[str, int])
+    assert is_instance({"a": 1}, tippo.Mapping[six.text_type, int])
     assert is_instance({"a": 1}, tippo.Dict[str, int])
     assert is_instance(["a"], tippo.Iterable[str])
     assert is_instance(["a"], tippo.List[str])
